@@ -7,7 +7,7 @@ import json
 from datetime import datetime
 from uuid import UUID
 from google.protobuf.json_format import MessageToJson
-import sys
+import os
 
 from indykite_sdk.utils.hash_methods import encrypt_bcrypt, encrypt_sha256
 from indykite_sdk.identity import IdentityClient
@@ -25,6 +25,7 @@ from indykite_sdk.model.is_authorized import IsAuthorizedResource
 from indykite_sdk.model.tenant import Tenant
 import logging
 
+
 class ParseKwargs(argparse.Action):
     def __call__(self, parser, namespace, values, option_string=None):  # pragma: no cover
         setattr(namespace, self.dest, dict())
@@ -1054,14 +1055,13 @@ Property ID and value of the property where the value is a reference
     elif command == "register_service_account_credential_pem":
         service_account_id = args.service_account_id
         display_name = args.display_name
-        default_tenant_id = args.default_tenant_id
         pem = None
         t = datetime.now().timestamp()
         expire_time_in_seconds = int(t) + 2678400 # now + one month example
         service_account_credential_response = client_config.register_service_account_credential_pem(service_account_id,
                                                                                              display_name, pem,
                                                                                              expire_time_in_seconds,
-                                                                                             default_tenant_id, [])
+                                                                                             [])
         if service_account_credential_response:
             print_credential(service_account_credential_response)
         else:
@@ -1084,18 +1084,18 @@ Property ID and value of the property where the value is a reference
         display_name = args.display_name
         description = args.description
 
-        default_from_address_address="test+config@indykite.com"
+        default_from_address_address=os.getenv('INDYKITE_DEFAULT_FROM')
         default_from_address_name="Test Config"
 
         sendgrid = SendGridProviderConfig(
-            api_key="263343b5-983e-4d73-b666-069a98f1ef55",
+            api_key=os.getenv('SENDGRID_KEY'),
             sandbox_mode=True,
-            ip_pool_name=wrappers.StringValue(value="100.45.21.65.25"),
+            ip_pool_name=wrappers.StringValue(value=os.getenv('SENDGRID_IP')),
             host=wrappers.StringValue(value="https://api.sendgrid.com")
         )
 
-        message_from = Email(address='test+from@indykite.com', name='Test From')
-        message_to = [Email(address='test+to@indykite.com', name='Test To')]
+        message_from = Email(address=os.getenv('INDYKITE_DEFAULT_FROM'), name='Test From')
+        message_to = [Email(address=os.getenv('INDYKITE_DEFAULT_TO'), name='Test To')]
         message_subject = "subject"
         message_text_content = "content text"
         message_html_content = "<html><body>content html</body></html>"
@@ -1532,7 +1532,7 @@ Property ID and value of the property where the value is a reference
             state="DIGITAL_TWIN_STATE_ACTIVE",
             password=PasswordCredential(
                 email=EmailIdentity(
-                    email="test2101@example.com",
+                    email="test2105@example.com",
                     verified=True
                 ),
                 value="password"
@@ -1544,7 +1544,7 @@ Property ID and value of the property where the value is a reference
                 state="DIGITAL_TWIN_STATE_ACTIVE",
                 password=PasswordCredential(
                     email=EmailIdentity(
-                        email="test2102@example.com",
+                        email="test2106@example.com",
                         verified=True
                     ),
                     value="password"
@@ -1556,7 +1556,7 @@ Property ID and value of the property where the value is a reference
                 state="DIGITAL_TWIN_STATE_ACTIVE",
                 password=PasswordCredential(
                     email=EmailIdentity(
-                        email="test2104@example.com",
+                        email="test2107@example.com",
                         verified=True
                     ),
                     value="password"
