@@ -1,8 +1,11 @@
 from indykite_sdk.indykite.identity.v1beta2 import identity_management_api_pb2 as pb2
 from google.protobuf import struct_pb2
+import sys
+import indykite_sdk.utils.logger as logger
 
 
 def enrich_token(self, user_token: str, token_claims: dict, session_claims: dict):
+    sys.excepthook = logger.handle_excepthook
     try:
         token_struct = struct_pb2.Struct()
         if token_claims is not None:
@@ -20,8 +23,7 @@ def enrich_token(self, user_token: str, token_claims: dict, session_claims: dict
             )
         )
     except Exception as exception:
-        print(exception)
-        return None
+        return logger.logger_error(exception)
 
     if not response:
         return None
